@@ -11,7 +11,7 @@ class FactTestCase(unittest.TestCase):
     #region Constructor
 
     def __init__(self, sparkUtility: Spark, tableDataFrame: DataFrame, fieldInfo: {(str, type)}, linkedDimensionTables: [(str, str)], databaseName: str, tableName: str, tableCount: int, customEvents: [TestEvent], excludeFromAggregation: [str] = [], methodName: str = "runTest"):
-        super(TestCaseFact, self).__init__(methodName)
+        super(FactTestCase, self).__init__(methodName)
         self.__spark = sparkUtility
         self.__tableDataFrame = tableDataFrame
         self.__fieldInfo = fieldInfo
