@@ -3,20 +3,20 @@ from Microsoft.Finance.DataStandards.UnitTest.TestCase.CommonTestCase import Com
 from Microsoft.Finance.DataStandards.UnitTest.TestSuite.BaseTestSuite import BaseTestSuite
 from pyspark.sql.session import SparkSession
 
-class TestSuiteBridge(BaseTestSuite):
+class BridgeTestSuite(BaseTestSuite):
 
     #region Constructor
 
     def __init__(self, sparkSession: SparkSession, databaseName: str, tableName: str):
-        super(TestSuiteBridge, self).__init__(sparkSession, databaseName, tableName)
+        super(BridgeTestSuite, self).__init__(sparkSession, databaseName, tableName)
 
     #endregion
 
     #region Class Methods
 
     def queue_tests(self) -> None:
-        bridgeTestCase = TestCaseBridge(self.FieldInfo, self.CustomEvents)
-        commonTestCase = TestCaseCommon(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
+        bridgeTestCase = BridgeTestCase(self.FieldInfo, self.CustomEvents)
+        commonTestCase = CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
         self.TestSuite.addTest(bridgeTestCase)
         self.TestSuite.addTest(commonTestCase)
 
